@@ -17,7 +17,7 @@ coerce 'Net::CLI::Interact::Transport::Telnet::Options'
 
 package Net::CLI::Interact::Transport::Telnet;
 BEGIN {
-  $Net::CLI::Interact::Transport::Telnet::VERSION = '1.110891';
+  $Net::CLI::Interact::Transport::Telnet::VERSION = '1.110900';
 }
 
 use Moose;
@@ -56,7 +56,7 @@ Net::CLI::Interact::Transport::Telnet::Options - TELNET based CLI connection
 
 =head1 VERSION
 
-version 1.110891
+version 1.110900
 
 =head1 DECRIPTION
 
@@ -72,13 +72,13 @@ which provides TELNET.
 
 =head2 runtime_options
 
-Based on the C<connect_options> hash provided to C<Net::CLI::Interact> on
-construction, selects attributes to provide to C<app> on the command line.
-Supported attributes:
+Based on the C<connect_options> hash provided to Net::CLI::Interact on
+construction, selects and formats parameters to provide to C<app> on the
+command line. Supported attributes:
 
 =over 4
 
-=item host
+=item host (required)
 
 Host name or IP address of the host to which the TELNET application is to
 connect.
